@@ -176,7 +176,7 @@ def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dicti
     # make a copy of the dataset
     df_preleads_clean = df.copy()
     # Set Types
-    df_preleads_clean= devutils.set_dataframe_columntypes(df_leads_clean)
+    df_preleads_clean= devutils.set_dataframe_columntypes(df_preleads_clean)
 
     # Map industry dictionary
     df_preleads_clean['Industry']= df_preleads_clean['Industry'].map(industry_dictionary)
